require 'net/http'
require 'json'
require 'faraday'

class CookbookClient
  class << self
    attr_accessor :url, :email, :password
  end

  def self.http
    if !@email.nil? && !@password.nil?
      return Faraday.new url: @url do |conn|
        conn.basic_auth(@email, @password)
        conn.adapter :net_http
      end
    end
    Faraday.new url: @url
  end

  def self.form_helpers
    response = JSON.parse(http.get('/api/v1/recipes/form_helper').body)
    {
      cuisines: (
        response['cuisines'].map { |c| [c['id'], c['name']] }
      ).to_h,
      recipe_types: (
        response['recipe_types'].map { |rp| [rp['id'], rp['name']] }
      ).to_h
    }
  end

  def self.format_recipes(recipes:, content_class:)
    recipes = [recipes] unless recipes.is_a?(Array)
    helpers = form_helpers
    recipes.map do |r|
      r['cuisine'] = helpers[:cuisines][r['cuisine_id']]
      r['recipe_type'] = helpers[:recipe_types][r['recipe_type_id']]
      content_class.new info: r
    end
  end
end

require 'cookbook_client/recipe'
require 'cookbook_client/cuisine'
require 'cookbook_client/recipe_type'
