class CookbookClient::Recipe
  attr_accessor :title, :cook_time, :cook_method, :ingredients, :difficulty,
                :recipe_type, :cuisine, :id, :created_at, :updated_at,
                :cuisine_id, :recipe_type_id, :featured, :user_id

  # rubocop:disable Metrics/AbcSize, Metrics/MethodLength
  def initialize(info:)
    @title = info['title']
    @cook_time = info['cook_time']
    @cook_method = info['cook_method']
    @ingredients = info['ingredients']
    @difficulty = info['difficulty']
    @recipe_type = info['recipe_type']
    @cuisine = info['cuisine']
    @id = info['id']
    @created_at = info['created_at']
    @updated_at = info['updated_at']
    @cuisine_id = info['cuisine_id']
    @recipe_type_id = info['recipe_type_id']
    @featured = info['featured']
    @user_id = info['user_id']
  end
  # rubocop:enable Metrics/AbcSize, Metrics/MethodLength

  def self.all
    CookbookClient.format_recipes(
      recipes: JSON.parse(CookbookClient.http.get('/api/v1/recipes/all').body),
      content_class: self
    )
  end

  def self.find(id)
    response = CookbookClient.http.get("/api/v1/recipes/#{id}/search")

    if response.status != 200
      raise StandardError, "Error #{response.status} - #{response.body}"
    end

    CookbookClient.format_recipes(
      recipes: JSON.parse(response.body),
      content_class: self
    ).first
  end

  def self.destroy(id)
    response = CookbookClient.http.delete("/api/v1/recipes/#{id}")

    if response.status != 200
      raise StandardError, "Error #{response.status} - #{response.body}"
    end

    CookbookClient.format_recipes(
      recipes: JSON.parse(response.body),
      content_class: self
    ).first
  end
end
